==> react-script-criteo-1.5.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { Component } from 'react';
import ScriptLoader from '@s-ui/react-script-loader';
var CRITEO_SCRIPT_URL = '//static.criteo.net/js/ld/ld.js';

var ScriptCriteo = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ScriptCriteo, _Component);

  function ScriptCriteo() {
    return _Component.apply(this, arguments) || this;
  }

  var _proto = ScriptCriteo.prototype;

  _proto.initCriteo = function initCriteo() {
    var _window$criteo_q;

    var _this$props = this.props,
        accountIds = _this$props.accountIds,
        customerId = _this$props.customerId,
        siteType = _this$props.siteType,
        email = _this$props.email,
        hashedEmail = _this$props.hashedEmail,
        pageEvent = _this$props.pageEvent;
    var criteoData = [{
      event: 'setAccount',
      account: accountIds
    }, {
      event: 'setSiteType',
      type: siteType
    }, customerId && {
      event: 'setCustomerId',
      id: customerId
    }, !hashedEmail && {
      event: 'setEmail',
      email: email
    }, hashedEmail && {
      event: 'setHashedEmail',
      email: hashedEmail
    }, pageEvent].filter(Boolean); // Push events to criteo

    window.criteo_q = window.criteo_q || [];

    (_window$criteo_q = window.criteo_q).push.apply(_window$criteo_q, criteoData);
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate() {
    return false;
  };

  _proto.render = function render() {
    var _this = this;

    return /*#__PURE__*/_jsx(ScriptLoader, {
      src: CRITEO_SCRIPT_URL,
      verifier: function verifier() {
        return window && window.criteo_q;
      },
      render: function render() {
        return _this.initCriteo() || null;
      }
    });
  };

  return ScriptCriteo;
}(Component);

ScriptCriteo.displayName = 'ScriptCriteo';
ScriptCriteo.defaultProps = {
  email: '',
  hashedEmail: ''
};
export default ScriptCriteo;

==> react-script-criteo-1.6.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Component } from 'react';
import PropTypes from 'prop-types';
import ScriptLoader from '@s-ui/react-script-loader';
import { jsx as _jsx } from "react/jsx-runtime";
var CRITEO_SCRIPT_URL = '//static.criteo.net/js/ld/ld.js';
var ScriptCriteo = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ScriptCriteo, _Component);
  function ScriptCriteo() {
    return _Component.apply(this, arguments) || this;
  }
  var _proto = ScriptCriteo.prototype;
  _proto.initCriteo = function initCriteo() {
    var _window$criteo_q;
    var _this$props = this.props,
      accountIds = _this$props.accountIds,
      customerId = _this$props.customerId,
      siteType = _this$props.siteType,
      email = _this$props.email,
      hashedEmail = _this$props.hashedEmail,
      pageEvent = _this$props.pageEvent;
    var criteoData = [{
      event: 'setAccount',
      account: accountIds
    }, {
      event: 'setSiteType',
      type: siteType
    }, customerId && {
      event: 'setCustomerId',
      id: customerId
    }, !hashedEmail && {
      event: 'setEmail',
      email: email
    }, hashedEmail && {
      event: 'setHashedEmail',
      email: hashedEmail
    }, pageEvent].filter(Boolean);

    // Push events to criteo
    window.criteo_q = window.criteo_q || [];
    (_window$criteo_q = window.criteo_q).push.apply(_window$criteo_q, criteoData);
  };
  _proto.shouldComponentUpdate = function shouldComponentUpdate() {
    return false;
  };
  _proto.render = function render() {
    var _this = this;
    return /*#__PURE__*/_jsx(ScriptLoader, {
      src: CRITEO_SCRIPT_URL,
      verifier: function verifier() {
        return window && window.criteo_q;
      },
      render: function render() {
        return _this.initCriteo() || null;
      }
    });
  };
  return ScriptCriteo;
}(Component);
ScriptCriteo.displayName = 'ScriptCriteo';
ScriptCriteo.defaultProps = {
  email: '',
  hashedEmail: ''
};
export default ScriptCriteo;
